/*
  Index.html file for ESP32 Laser Harp

  NOTE: There are probably way better ways to do this but
        I am no web UI designer

  Concept, Design and Implementation by: Craig A. Lindley
  Last Update: 12/28/2022
*/

const char index_html[] PROGMEM = R"rawliteral(
<!DOCTYPE HTML><html>
<head>
<script>
  var gateway = `ws://${window.location.hostname}/ws`;
  var websocket;
  window.addEventListener('load', initWebSocket());
  function initWebSocket() {
    console.log('Trying to open a WebSocket connection...');
    websocket = new WebSocket(gateway);
    websocket.onopen    = onOpen;
    websocket.onclose   = onClose;
    websocket.onmessage = onMessage;
  }
  function onOpen(event) {
    console.log('Connection opened');
  }
  function onClose(event) {
    console.log('Connection closed');
    setTimeout(initWebSocket, 2000);
  }
  function onMessage(event) {
    console.log(event.data);

    // Clear the program dropdown list
    var select = document.getElementById("program");
    var length = select.options.length;
    for (i = length-1; i >= 0; i--) {
      select.options[i] = null;
    }
    // Reload program dropdown list with new programs  
    var options = event.data.split(",");
    var select = document.getElementById('program');
    for (var i=0; i<options.length; i++) {
      select.options[i] = new Option(options[i], i);
    }
  }
  </script>

  <title>Laser Harp</title>
  <meta name="viewport" content="width=256, initial-scale=1">
  <link rel="icon" href="data:,">
  <style>
  html {
    font-family: Arial, Helvetica, sans-serif;
    text-align: center;
  }
  h1 {
    font-size: 1.1rem;
    font-weight: bold;
    color: white;
  }
  .topnav {
    overflow: hidden;
    background-color: #143642;
  }
  .center-horizonally {
    display: flex;
    justify-content: center;
  }
  .radiobuttons {
    text-align: center;
    font-weight: light;
  }
  </style>
</head>
<body>
  <div>
    <div class="topnav">
      <h1>Craig's Laser Harp Control</h1>
   </div>
    <div>
      <p>Key</p>
      <select id ="key" name="key" onchange="websocket.send('KY:' + this.value);">
       <option value='0'>C</option>
       <option value='1'>Db</option>
       <option value='2'>D</option>
       <option value='3'>Eb</option>
       <option value='4'>E</option>
       <option value='5'>F</option>
       <option value='6'>F#</option>
       <option value='7'>G</option>
       <option value='8'>Ab</option>
       <option value='9'>A</option>
       <option value='10'>Bb</option>
       <option value='11'>B</option>
     </select>
    </div>
    <div>
      <p>Octave Shift</p>
      <select id ="octave" name="octave" onchange="websocket.send('OS:' + this.value);">
       <option value='0'>-3</option>
       <option value='1'>-2</option>
       <option value='2'>-1</option>
       <option value='3' selected>0</option>
       <option value='4'>+1</option>
       <option value='5'>+2</option>
       <option value='6'>+3</option>
     </select>
    </div>
    <div>
      <p>Scale</p>
      <select id ="scale" name="scale" onchange="websocket.send('SC:' + this.value);">
       <option value='0'>Chromatic</option>
       <option value='1'>Major</option>
       <option value='2'>Dorian</option>
       <option value='3'>Phrygian</option>
       <option value='4'>Lydian</option>
       <option value='5'>Mixolydian</option>
       <option value='6'>Natural Minor</option>
       <option value='7'>Locrian</option>
       <option value='8'>Freygish</option>
       <option value='9'>Melodic Minor</option>
       <option value='10'>Harmonic Minor</option>
       <option value='11'>Major Blues</option>
       <option value='12'>Minor Blues</option>
       <option value='13'>Major Pentatonic</option>
       <option value='14'>Minor Pentatonic</option>
       <option value='15'>Diminish</option>
       <option value='16'>Combi Diminish</option>
       <option value='17'>Raga Bhairav</option>
       <option value='18'>Raga Gamansrama</option>
       <option value='19'>Raga Todi</option>
       <option value='20'>Spanish</option>
       <option value='21'>Gypsy</option>
       <option value='22'>Arabian</option>
       <option value='23'>Egyptian</option>
       <option value='24'>Hawaiian</option>
       <option value='25'>Bali Pelog</option>
       <option value='26'>Japan</option>
       <option value='27'>Ryukyu</option>
       <option value='28'>Wholetone</option>
       <option value='29'>Augmented</option>
       <option value='30'>Prometheus</option>
       <option value='31'>Tritone</option>
      </select>
    </div>
    <div>
      <p>Program Category</p>
      <select id ="programcat" name="programcat" onchange="websocket.send('PC:' + this.value);">
       <option value='0'>Pianos</option>
       <option value='1'>Chromatic Percussion</option>
       <option value='2'>Organs</option>
       <option value='3'>Guitars</option>
       <option value='4'>Basses</option>
       <option value='5'>Strings</option>
       <option value='6'>Ensembles</option>
       <option value='7'>Brass</option>
       <option value='8'>Reeds</option>
       <option value='9'>Pipes</option>
       <option value='10'>Synth Leads</option>
       <option value='11'>Synth Pads</option>
       <option value='12'>Synth Effects</option>
       <option value='13'>Ethnics</option>
       <option value='14'>Percussives</option>
       <option value='15'>Sound Effects</option>
      </select>
   </div>
      <p>Program</p>
      <select id ="program" name="program" onchange="websocket.send('PG:' + this.value);">
       <option value='0'>Acoustic Grand</option>
       <option value='1'>Bright Acoustic</option>
       <option value='2'>Electric Grand</option>
       <option value='3'>Honky Tonk</option>
       <option value='4'>Electric 1</option>
       <option value='5'>Electric 2</option>
       <option value='6'>Harpsichord</option>
       <option value='7'>Clavinet</option>
      </select>
   </div>
   <div>
     <p>MIDI Channel</p>
     <select id ="channel" name="channel" onchange="websocket.send('MC:' + this.value);">
       <option value='1'>1</option>
       <option value='2'>2</option>
       <option value='3'>3</option>
       <option value='4'>4</option>
       <option value='5'>5</option>
       <option value='6'>6</option>
       <option value='7'>7</option>
       <option value='8'>8</option>
       <option value='9'>9</option>
       <option value='10'>10</option>
       <option value='11'>11</option>
       <option value='12'>12</option>
       <option value='13'>13</option>
       <option value='14'>14</option>
       <option value='15'>15</option>
       <option value='16'>16</option>
      </select>
   </div>
   <br>
   <div>
    <fieldset>
      <legend>String Order</legend>
      <div class="radiobuttons">
        <div>
          <label for="ltor">Left to Right</label>
          <input type="radio" name="SO" id="ltor" value="0" checked onclick="websocket.send('SO:0')">
       </div>
       <div>
         <label for="rtol">Right to Left</label>
         <input type="radio" name="SO" id="rtol" value="1" onclick="websocket.send('SO:1')">
     </div>
   </fieldset>
   <br>
  </div>
   <div>
    <fieldset>
      <legend>Effects</legend>
      <div>
        <p>Volume</p>
        <input type="range" id="volslider" min="0" max="127" value="64" oninput="websocket.send('VU:' + this.value)"/>
     </div>
      <div>
        <p>Modulation</p>
        <input type="range" id="modulationslider" min="0" max="127" value="0" oninput="websocket.send('CM:' + this.value)"/>
     </div>
     <div>
        <p>Reverb</p>
        <input type="range" id="reverbslider" min="0" max="127" value="0" oninput="websocket.send('RV:' + this.value)"/>
     </div>
      <div>
        <p>Chorus</p>
        <input type="range" id="chorusslider" min="0" max="127" value="0" oninput="websocket.send('CH:' + this.value)"/>
     </div>
      <div>
        <p>Portamento</p>
        <input type="range" id="portamentoslider" min="0" max="127" value="0" oninput="websocket.send('PT:' + this.value)"/>
     </div>
   </fieldset>
  </div>
</div>

</body>
</html>
)rawliteral";
